@@ -975,18 +975,18 @@ class Model(_Base):
             'Model must have a non-zero angle_tolerance to perform geometry checks.'
         tol = self.tolerance
         ang_tol = self.angle_tolerance
-        # perform several checks for key geometry rules
+        # perform several checks for Face3D geometry rules
         msgs.append(self.check_self_intersecting(tol, False))
         msgs.append(self.check_planar(tol, False))
-        msgs.append(self.check_sub_faces_valid(tol, ang_tol, False))
-        msgs.append(self.check_rooms_solid(tol, ang_tol, False))
-        # remove colinear vertices to ensure that this doesn't create faces with 2 edges
-        # this is a requirement for energy simulation
+        # remove colinear vertices to ensure that this doesn't create faces with <3 edges
         for room in self.rooms:
             try:
                 room.remove_colinear_vertices_envelope(tol)
             except ValueError as e:
                 msgs.append(str(e))
+        # perform geometry checks related to parent-child relationships
+        msgs.append(self.check_sub_faces_valid(tol, ang_tol, False))
+        msgs.append(self.check_rooms_solid(tol, ang_tol, False))
         # check the extension attributes
         msgs.extend(self._properties._check_extension_attr())
         # output a final report of errors or raise an exception
@@ -1156,13 +1156,15 @@ class Model(_Base):
                 intersects with itself (like a bowtie). Default: True.
         """
         msgs = []
-        for face in self.faces:
+        for room in self.rooms:
+            msgs.append(room.check_self_intersecting(tolerance, raise_exception=False))
+        for face in self.orphaned_faces:
             msgs.append(face.check_self_intersecting(tolerance, raise_exception=False))
-        for shd in self.shades:
+        for shd in self.orphaned_shades:
             msgs.append(shd.check_self_intersecting(tolerance, raise_exception=False))
-        for ap in self.apertures:
+        for ap in self.orphaned_apertures:
             msgs.append(ap.check_self_intersecting(tolerance, raise_exception=False))
-        for dr in self.doors:
+        for dr in self.orphaned_doors:
             msgs.append(dr.check_self_intersecting(tolerance, raise_exception=False))
         full_msgs = [msg for msg in msgs if msg != '']
         full_msg = '\n'.join(full_msgs)
